==> labthings-1.0.0.tar.gz: labthings-1.0.0/src/labthings/marshalling/args.py <==
import logging
from functools import update_wrapper, wraps

from flask import abort, request
from marshmallow.exceptions import ValidationError
from webargs import flaskparser

from ..fields import Field
from ..schema import FieldSchema


class use_body:
    """Gets the request body as a single value and adds it as a positional argument"""

    def __init__(self, schema, **kwargs):
        self.schema = schema

    def __call__(self, f):
        # Wrapper function
        @wraps(f)
        def wrapper(*args, **kwargs):
            """

            :param *args: 
            :param **kwargs: 

            """
            # Get data from request
            data = request.data or None

            # If no data is there
            if not data:
                # If data is required
                if self.schema.required:
                    # Abort
                    return abort(400)
                # Otherwise, look for the schema fields 'missing' property
                if self.schema.missing:
                    data = self.schema.missing

            # Serialize data if it exists
            if data:
                try:
                    data = FieldSchema(self.schema).deserialize(data)
                except ValidationError as e:
                    logging.error(e)
                    return abort(400)

            # Inject argument and return wrapped function
            return f(*args, data, **kwargs)

        return wrapper


class use_args:
    """Equivalent to webargs.flask_parser.use_args"""

    def __init__(self, schema, **kwargs):
        self.schema = schema

        if isinstance(schema, Field):
            self.wrapper = use_body(schema, **kwargs)
        else:
            self.wrapper = flaskparser.use_args(schema, **kwargs)

    def __call__(self, f):
        # Wrapper function
        update_wrapper(self.wrapper, f)
        return self.wrapper(f)

==> labthings-1.1.6.tar.gz: labthings-1.1.6/src/labthings/marshalling/args.py <==
import logging
from functools import update_wrapper, wraps
from typing import Callable, Dict, Union

from flask import abort, request
from marshmallow.exceptions import ValidationError
from webargs import flaskparser

from ..fields import Field
from ..schema import FieldSchema, Schema


class use_body:
    """Gets the request body as a single value and adds it as a positional argument"""

    def __init__(
        self, schema: Union[Schema, Field, Dict[str, Union[Field, type]]], **_
    ):
        self.schema = schema

    def __call__(self, f: Callable):
        # Wrapper function
        @wraps(f)
        def wrapper(*args, **kwargs):
            """

            :param *args:
            :param **kwargs:

            """
            # Get data from request
            data = request.get_json(silent=True) or request.data or None

            # If no data is there
            if not data:
                # If data is required
                if self.schema.required:
                    # Abort
                    return abort(400)
                # Otherwise, look for the schema fields 'missing' property
                if self.schema.missing:
                    data = self.schema.missing

            # Serialize data if it exists
            if data:
                try:
                    data = FieldSchema(self.schema).deserialize(data)
                except ValidationError as e:
                    logging.error(e)
                    return abort(400)

            # Inject argument and return wrapped function
            return f(*args, data, **kwargs)

        return wrapper


class use_args:
    """Equivalent to webargs.flask_parser.use_args"""

    def __init__(
        self, schema: Union[Schema, Field, Dict[str, Union[Field, type]]], **kwargs
    ):
        self.schema = schema

        if isinstance(schema, Field):
            self.wrapper = use_body(schema, **kwargs)
        else:
            self.wrapper = flaskparser.use_args(schema, **kwargs)

    def __call__(self, f: Callable):
        # Wrapper function
        update_wrapper(self.wrapper, f)
        return self.wrapper(f)
